#-------------------------------------------------------------------------------
macro (HDF_SET_LIB_OPTIONS libtarget libname libtype libpackage)
  set (LIB_OUT_NAME "${libname}")
  # SOVERSION passed in ARGN when shared
  if (${libtype} MATCHES "SHARED")
    set (PACKAGE_SOVERSION ${${libpackage}_PACKAGE_SOVERSION})
    set (PACKAGE_COMPATIBILITY ${${libpackage}_SOVERS_INTERFACE}.0.0)
    set (PACKAGE_CURRENT ${${libpackage}_SOVERS_INTERFACE}.${${libpackage}_SOVERS_MINOR}.0)
    if (WIN32)
      set (LIBHDF_VERSION ${${libpackage}_PACKAGE_VERSION_MAJOR})
    else ()
      set (LIBHDF_VERSION ${${libpackage}_PACKAGE_SOVERSION_MAJOR})
    endif ()
    set_target_properties (${libtarget} PROPERTIES VERSION ${PACKAGE_SOVERSION})
    if (WIN32)
        set (${LIB_OUT_NAME} "${LIB_OUT_NAME}-${LIBHDF_VERSION}")
    else ()
        set_target_properties (${libtarget} PROPERTIES SOVERSION ${LIBHDF_VERSION})
    endif ()
    if (CMAKE_C_OSX_CURRENT_VERSION_FLAG)
      set_property(TARGET ${libtarget} APPEND PROPERTY
          LINK_FLAGS "${CMAKE_C_OSX_CURRENT_VERSION_FLAG}${PACKAGE_CURRENT} ${CMAKE_C_OSX_COMPATIBILITY_VERSION_FLAG}${PACKAGE_COMPATIBILITY}"
      )
    endif ()
  endif ()
  HDF_SET_LIB_OPTIONS (${libtarget} ${LIB_OUT_NAME} ${libtype})

  #-- Apple Specific install_name for libraries
  if (APPLE)
    option (HDF_BUILD_WITH_INSTALL_NAME "Build with library install_name set to the installation path" OFF)
    if (HDF_BUILD_WITH_INSTALL_NAME)
      set_target_properties (${libtarget} PROPERTIES
          INSTALL_NAME_DIR "${CMAKE_INSTALL_PREFIX}/lib"
          BUILD_WITH_INSTALL_RPATH ${HDF_BUILD_WITH_INSTALL_NAME}
      )
    endif ()
  endif ()
endmacro ()

macro (HDF_COPY_REFERENCE_FILES refname)
  if (COMPARE_TESTING)
    set (testdest "${PROJECT_BINARY_DIR}/${hdf5app}")
    #message (STATUS " Copying ${hdf5app}.tst")
    add_custom_command (
        TARGET     jh5_${hdf5app}
        POST_BUILD
        COMMAND    ${CMAKE_COMMAND}
        ARGS       -E copy_if_different ${PROJECT_SOURCE_DIR}/testfiles/${hdf5app}.tst ${testdest}.tst
    )
    if (HDF5_BUILD_TOOLS AND COMPARE_TESTING)
      add_custom_command (
          TARGET     jh5_${hdf5app}
          POST_BUILD
          COMMAND    ${CMAKE_COMMAND}
          ARGS       -E copy_if_different ${PROJECT_SOURCE_DIR}/testfiles/${hdf5app}.ddl ${testdest}.ddl
      )
    endif ()
  endif ()
endmacro ()
